#!/usr/local/bin/perl -w

=head1 NAME

revml.t - testing of vcp revml in and out

=cut

use strict ;

use Carp ;
use File::Spec ;
use Test ;
use VCP::TestUtils ;

my @vcp = vcp_cmd ;



my $t = -d 't' ? 't/' : '' ;

my @tests = (
##
## Empty imports, used here just to see if commad line parsing is ok and
## that a really simple file can make it through the XML parser ok.
##
sub {
   run [ @vcp, "revml:-", "revml:" ], \"<revml/>" ;
   ok $?, 0, "`vcp revml:- revml:` return value"  ;
},

sub {
   run [ @vcp, "-", "-" ], \"<revml/>" ;
   ok $?, 0, "`vcp revml:- revml:` return value"  ;
},

sub {
   run [ @vcp, "-", ], \"<revml/>" ;
   ok $?, 0, "`vcp revml:- revml:` return value"  ;
},

sub {
   run [ @vcp, ], \"<revml/>" ;
   ok $?, 0, "`vcp revml:- revml:` return value"  ;
},
( map {
   my $type = $_ ;

   ##
   ## Idempotency tests
   ##
   ## These depend on the "test-foo-in.revml" files built in the makefile.
   ## See MakeMaker.PL for how those are generated.
   ##
   sub {
      eval {
	 my $out ;
	 my $infile  = $t . "test-$type-in-0.revml" ;
	 ## $in and $out allow us to avoide execing diff most of the time.
	 run [ @vcp, "$infile", "-", "--sort-by=name,rev_id" ], \undef, \$out;

	 my $in = slurp( $infile ) ;
	 assert_eq $infile, $in, $out ;
      } ;
      ok $@ || '', '', "diff of test-$type-in-0.revml" ;
   },
} qw( revml cvs p4 ) )
) ;

plan tests => scalar( @tests ) ;

$_->() for @tests ;
